Python: module csp

csp (version 0.0.1) | index csp.py

`This package implements a web server to run scripts or
executables from the command line and display the result
in a web interface.
This file implement a Content-Security-Policy debug page.`

Modules
`` |  |
json |  |  |

Functions
`` |  | debug(environ: os._Environ, user: ~User, configuration: ~ServerConfiguration, code: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This function implement a debug page.`

Data
`` |  | Dict = typing.Dict List = typing.List ServerConfiguration = ~ServerConfiguration Tuple = typing.Tuple User = ~User __author_email__ = 'mauricelambert434@gmail.com' __copyright__ = '\nWebScripts Copyright (C) 2021 Maurice Lambert...ome to redistribute it\nunder certain conditions.\n' __description__ = 'This package implements a web server to run scri...e implement a Content-Security-Policy debug page.' __license__ = 'GPL-3.0 License' __maintainer__ = 'Maurice Lambert' __maintainer_email__ = 'mauricelambert434@gmail.com' __url__ = 'https://github.com/mauricelambert/WebScripts' copyright = '\nWebScripts Copyright (C) 2021 Maurice Lambert...ome to redistribute it\nunder certain conditions.\n' csp_report = {'report': 'No CSP report yet.'} license = 'GPL-3.0 License'

Author
`` |  | Maurice Lambert